==> kubernetes-model-resource-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimTemplateSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ResourceClaimTemplateSpecFluentImpl<A extends ResourceClaimTemplateSpecFluent<A>> extends BaseFluent<A> implements ResourceClaimTemplateSpecFluent<A>{
  public ResourceClaimTemplateSpecFluentImpl() {
  }
  public ResourceClaimTemplateSpecFluentImpl(ResourceClaimTemplateSpec instance) {
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ObjectMetaBuilder metadata;
  private ResourceClaimSpecBuilder spec;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> withNewMetadata() {
    return new ResourceClaimTemplateSpecFluentImpl.MetadataNestedImpl();
  }
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ResourceClaimTemplateSpecFluentImpl.MetadataNestedImpl(item);
  }
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ResourceClaimTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ResourceClaimSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ResourceClaimSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ResourceClaimSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ResourceClaimTemplateSpecFluent.SpecNested<A> withNewSpec() {
    return new ResourceClaimTemplateSpecFluentImpl.SpecNestedImpl();
  }
  public ResourceClaimTemplateSpecFluent.SpecNested<A> withNewSpecLike(ResourceClaimSpec item) {
    return new ResourceClaimTemplateSpecFluentImpl.SpecNestedImpl(item);
  }
  public ResourceClaimTemplateSpecFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ResourceClaimTemplateSpecFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ResourceClaimSpecBuilder().build());
  }
  public ResourceClaimTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(ResourceClaimSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceClaimTemplateSpecFluentImpl that = (ResourceClaimTemplateSpecFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ResourceClaimTemplateSpecFluent.MetadataNested<N>> implements ResourceClaimTemplateSpecFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ResourceClaimTemplateSpecFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ResourceClaimSpecFluentImpl<ResourceClaimTemplateSpecFluent.SpecNested<N>> implements ResourceClaimTemplateSpecFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ResourceClaimSpec item) {
      this.builder = new ResourceClaimSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ResourceClaimSpecBuilder(this);
    }
    ResourceClaimSpecBuilder builder;
    public N and() {
      return (N) ResourceClaimTemplateSpecFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimTemplateSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ResourceClaimTemplateSpecFluentImpl<A extends ResourceClaimTemplateSpecFluent<A>> extends BaseFluent<A> implements ResourceClaimTemplateSpecFluent<A>{
  public ResourceClaimTemplateSpecFluentImpl() {
  }
  public ResourceClaimTemplateSpecFluentImpl(ResourceClaimTemplateSpec instance) {
    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ObjectMetaBuilder metadata;
  private ResourceClaimSpecBuilder spec;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ResourceClaimTemplateSpecFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ResourceClaimTemplateSpecFluentImpl.MetadataNestedImpl();
  }
  public ResourceClaimTemplateSpecFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ResourceClaimTemplateSpecFluentImpl.MetadataNestedImpl(item);
  }
  public ResourceClaimTemplateSpecFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ResourceClaimTemplateSpecFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ResourceClaimTemplateSpecFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ResourceClaimSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ResourceClaimSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ResourceClaimSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ResourceClaimTemplateSpecFluentImpl.SpecNested<A> withNewSpec() {
    return new ResourceClaimTemplateSpecFluentImpl.SpecNestedImpl();
  }
  public ResourceClaimTemplateSpecFluentImpl.SpecNested<A> withNewSpecLike(ResourceClaimSpec item) {
    return new ResourceClaimTemplateSpecFluentImpl.SpecNestedImpl(item);
  }
  public ResourceClaimTemplateSpecFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ResourceClaimTemplateSpecFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ResourceClaimSpecBuilder().build());
  }
  public ResourceClaimTemplateSpecFluentImpl.SpecNested<A> editOrNewSpecLike(ResourceClaimSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceClaimTemplateSpecFluentImpl that = (ResourceClaimTemplateSpecFluentImpl) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ResourceClaimTemplateSpecFluentImpl.MetadataNested<N>> implements ResourceClaimTemplateSpecFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ResourceClaimTemplateSpecFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ResourceClaimSpecFluentImpl<ResourceClaimTemplateSpecFluentImpl.SpecNested<N>> implements ResourceClaimTemplateSpecFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ResourceClaimSpec item) {
      this.builder = new ResourceClaimSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ResourceClaimSpecBuilder(this);
    }
    ResourceClaimSpecBuilder builder;
    public N and() {
      return (N) ResourceClaimTemplateSpecFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}
